
Changelog
=========

0.4.0 (2020-05-11)
------------------

* Move the code of the oemof.tools repository to a stand-alone repository.
* Use cookiecutter to create a wider testing structure and a more standardised
  package structure.
* Switch from nose to pytest
* Remove the version or commit logger
* Add test to increase test coverage
